package com.sun.jndi.toolkit.corba;

import javax.naming.NamingException;
import com.sun.jndi.cosnaming.CNCtx;
import javax.naming.Referenceable;
import javax.naming.Reference;
import java.util.Enumeration;
import java.util.Properties;
import java.util.Hashtable;
import java.rmi.RemoteException;
import java.lang.reflect.InvocationTargetException;
import javax.naming.ConfigurationException;
import org.omg.CORBA.Object;
import org.omg.CORBA.ORB;
import java.rmi.Remote;
import java.lang.reflect.Method;

public class CorbaUtils
{
    private static Method toStubMethod;
    private static Method connectMethod;
    private static Class<?> corbaStubClass;
    
    public CorbaUtils() {
    }
    
    public static org.omg.CORBA.Object remoteToCorba(Remote remote, ORB orb) throws ClassNotFoundException, ConfigurationException {
        synchronized (CorbaUtils.class) {
            if (CorbaUtils.toStubMethod == null) {
                initMethodHandles();
            }
        }
        Object invoke;
        try {
            invoke = CorbaUtils.toStubMethod.invoke(null, new Object[] { remote });
        }
        catch (InvocationTargetException ex) {
            Throwable targetException = ex.getTargetException();
            ConfigurationException ex2 = new ConfigurationException("Problem with PortableRemoteObject.toStub(); object not exported or stub not found");
            ex2.setRootCause(targetException);
            throw ex2;
        }
        catch (IllegalAccessException rootCause) {
            ConfigurationException ex3 = new ConfigurationException("Cannot invoke javax.rmi.PortableRemoteObject.toStub(java.rmi.Remote)");
            ex3.setRootCause(rootCause);
            throw ex3;
        }
        if (!CorbaUtils.corbaStubClass.isInstance(invoke)) {
            return null;
        }
        try {
            CorbaUtils.connectMethod.invoke(invoke, new Object[] { orb });
        }
        catch (InvocationTargetException ex4) {
            Throwable targetException2 = ex4.getTargetException();
            if (!(targetException2 instanceof RemoteException)) {
                ConfigurationException ex5 = new ConfigurationException("Problem invoking javax.rmi.CORBA.Stub.connect()");
                ex5.setRootCause(targetException2);
                throw ex5;
            }
        }
        catch (IllegalAccessException rootCause2) {
            ConfigurationException ex6 = new ConfigurationException("Cannot invoke javax.rmi.CORBA.Stub.connect()");
            ex6.setRootCause(rootCause2);
            throw ex6;
        }
        return (org.omg.CORBA.Object)invoke;
    }
    
    public static ORB getOrb(String value, int i, Hashtable<?, ?> hashtable) {
        Properties properties;
        if (hashtable != null) {
            if ((hashtable instanceof Properties)) {
                properties = (Properties)hashtable.clone();
            }
            else {
                properties = new Properties();
                Enumeration<Object> keys = hashtable.keys();
                while (keys.hasMoreElements()) {
                    String s = (String)keys.nextElement();
                    Object value2 = hashtable.get(s);
                    if ((value2 instanceof String)) {
                        properties.put(s, value2);
                    }
                    else {
                        continue;
                    }
                }
            }
        }
        else {
            properties = new Properties();
        }
        if (value != null) {
            properties.put("org.omg.CORBA.ORBInitialHost", value);
        }
        if (i >= 0) {
            properties.put("org.omg.CORBA.ORBInitialPort", "" + i);
        }
        if (hashtable != null) {
            Object value3 = hashtable.get("java.naming.applet");
            if (value3 != null) {
                return initAppletORB(value3, properties);
            }
        }
        return ORB.init(new String[0], properties);
    }
    
    public static boolean isObjectFactoryTrusted(Object o) throws NamingException {
        Reference reference = null;
        if ((o instanceof Reference)) {
            reference = (Reference)o;
        }
        else if ((o instanceof Referenceable)) {
            reference = ((Referenceable)(Referenceable)o).getReference();
        }
        if (reference != null && reference.getFactoryClassLocation() != null && !CNCtx.trustURLCodebase) {
            throw new ConfigurationException("The object factory is untrusted. Set the system property 'com.sun.jndi.cosnaming.object.trustURLCodebase' to 'true'.");
        }
        return true;
    }
    
    private static ORB initAppletORB(Object o, Properties properties) {
        try {
            Class<Object> forName = Class.forName("java.applet.Applet", true, null);
            if (!forName.isInstance(o)) {
                throw new ClassCastException(o.getClass().getName());
            }
            return (ORB)ORB.class.getMethod("init", new Class[] { forName, Properties.class }).invoke(null, new Object[] { o, properties });
        }
        catch (ClassNotFoundException ex) {
            throw new ClassCastException(o.getClass().getName());
        }
        catch (NoSuchMethodException detailMessage) {
            throw new AssertionError(detailMessage);
        }
        catch (InvocationTargetException detailMessage2) {
            Throwable cause = detailMessage2.getCause();
            if ((cause instanceof RuntimeException)) {
                throw (RuntimeException)cause;
            }
            if ((cause instanceof Error)) {
                throw (Error)cause;
            }
            throw new AssertionError(detailMessage2);
        }
        catch (IllegalAccessException detailMessage3) {
            throw new AssertionError(detailMessage3);
        }
    }
    
    private static void initMethodHandles() throws ClassNotFoundException {
        CorbaUtils.corbaStubClass = Class.forName("javax.rmi.CORBA.Stub");
        try {
            CorbaUtils.connectMethod = CorbaUtils.corbaStubClass.getMethod("connect", new Class[] { ORB.class });
        }
        catch (NoSuchMethodException ex) {
            throw new IllegalStateException("No method definition for javax.rmi.CORBA.Stub.connect(org.omg.CORBA.ORB)");
        }
        Class<Object> forName = Class.forName("javax.rmi.PortableRemoteObject");
        try {
            CorbaUtils.toStubMethod = forName.getMethod("toStub", new Class[] { Remote.class });
        }
        catch (NoSuchMethodException ex2) {
            throw new IllegalStateException("No method definition for javax.rmi.PortableRemoteObject.toStub(java.rmi.Remote)");
        }
    }
    
    static {
        CorbaUtils.toStubMethod = null;
        CorbaUtils.connectMethod = null;
        CorbaUtils.corbaStubClass = null;
    }
}
